import os
from contextlib import contextmanager

from pelican.plugins._utils import (
    get_namespace_plugins,
    get_plugin_name,
    load_plugins,
    plugin_enabled,
)
from pelican.plugins.signals import signal
from pelican.tests.dummy_plugins.normal_plugin import normal_plugin
from pelican.tests.support import unittest


@contextmanager
def tmp_namespace_path(path):
    """Context manager for temporarily appending namespace plugin packages

    path: path containing the `pelican` folder

    This modifies the `pelican.__path__` and lets the `pelican.plugins`
    namespace package resolve it from that.
    """
    # This avoids calls to internal `pelican.plugins.__path__._recalculate()`
    # as it should not be necessary
    import pelican

    old_path = pelican.__path__[:]
    try:
        pelican.__path__.append(os.path.join(path, "pelican"))
        yield
    finally:
        pelican.__path__ = old_path


class PluginTest(unittest.TestCase):
    _PLUGIN_FOLDER = os.path.join(
        os.path.abspath(os.path.dirname(__file__)), "dummy_plugins"
    )
    _NS_PLUGIN_FOLDER = os.path.join(_PLUGIN_FOLDER, "namespace_plugin")
    _NORMAL_PLUGIN_FOLDER = os.path.join(_PLUGIN_FOLDER, "normal_plugin")

    def test_namespace_path_modification(self):
        import pelican
        import pelican.plugins

        old_path = pelican.__path__[:]

        # not existing path
        path = os.path.join(self._PLUGIN_FOLDER, "foo")
        with tmp_namespace_path(path):
            self.assertIn(os.path.join(path, "pelican"), pelican.__path__)
            # foo/pelican does not exist, so it won't propagate
            self.assertNotIn(
                os.path.join(path, "pelican", "plugins"), pelican.plugins.__path__
            )
        # verify that we restored path back
        self.assertEqual(pelican.__path__, old_path)

        # existing path
        with tmp_namespace_path(self._NS_PLUGIN_FOLDER):
            self.assertIn(
                os.path.join(self._NS_PLUGIN_FOLDER, "pelican"), pelican.__path__
            )
            # /namespace_plugin/pelican exists, so it should be in
            self.assertIn(
                os.path.join(self._NS_PLUGIN_FOLDER, "pelican", "plugins"),
                pelican.plugins.__path__,
            )
        self.assertEqual(pelican.__path__, old_path)

    def test_get_namespace_plugins(self):
        # existing namespace plugins
        existing_ns_plugins = get_namespace_plugins()

        # with plugin
        with tmp_namespace_path(self._NS_PLUGIN_FOLDER):
            ns_plugins = get_namespace_plugins()
            self.assertEqual(len(ns_plugins), len(existing_ns_plugins) + 1)
            self.assertIn("pelican.plugins.ns_plugin", ns_plugins)
            self.assertEqual(
                ns_plugins["pelican.plugins.ns_plugin"].NAME, "namespace plugin"
            )

        # should be back to existing namespace plugins outside `with`
        ns_plugins = get_namespace_plugins()
        self.assertEqual(ns_plugins, existing_ns_plugins)

    def test_load_plugins(self):
        def get_plugin_names(plugins):
            return {get_plugin_name(p) for p in plugins}

        # existing namespace plugins
        existing_ns_plugins = load_plugins({})

        with tmp_namespace_path(self._NS_PLUGIN_FOLDER):
            # with no `PLUGINS` setting, load namespace plugins
            plugins = load_plugins({})
            self.assertEqual(len(plugins), len(existing_ns_plugins) + 1, plugins)
            self.assertEqual(
                {"pelican.plugins.ns_plugin"} | get_plugin_names(existing_ns_plugins),
                get_plugin_names(plugins),
            )

            # disable namespace plugins with `PLUGINS = []`
            SETTINGS = {"PLUGINS": []}
            plugins = load_plugins(SETTINGS)
            self.assertEqual(len(plugins), 0, plugins)

            # with `PLUGINS`, load only specified plugins

            # normal plugin
            SETTINGS = {
                "PLUGINS": ["normal_plugin"],
                "PLUGIN_PATHS": [self._NORMAL_PLUGIN_FOLDER],
            }
            plugins = load_plugins(SETTINGS)
            self.assertEqual(len(plugins), 1, plugins)
            self.assertEqual({"normal_plugin"}, get_plugin_names(plugins))

            # normal submodule/subpackage plugins
            SETTINGS = {
                "PLUGINS": [
                    "normal_submodule_plugin.subplugin",
                    "normal_submodule_plugin.subpackage.subpackage",
                ],
                "PLUGIN_PATHS": [self._NORMAL_PLUGIN_FOLDER],
            }
            plugins = load_plugins(SETTINGS)
            self.assertEqual(len(plugins), 2, plugins)
            self.assertEqual(
                {
                    "normal_submodule_plugin.subplugin",
                    "normal_submodule_plugin.subpackage.subpackage",
                },
                get_plugin_names(plugins),
            )

            # ensure normal plugins are loaded only once
            SETTINGS = {
                "PLUGINS": ["normal_plugin"],
                "PLUGIN_PATHS": [self._NORMAL_PLUGIN_FOLDER],
            }
            plugins = load_plugins(SETTINGS)
            for plugin in load_plugins(SETTINGS):
                # The second load_plugins() should return the same plugin
                # objects as the first one
                self.assertIn(plugin, plugins)

            # namespace plugin short
            SETTINGS = {"PLUGINS": ["ns_plugin"]}
            plugins = load_plugins(SETTINGS)
            self.assertEqual(len(plugins), 1, plugins)
            self.assertEqual({"pelican.plugins.ns_plugin"}, get_plugin_names(plugins))

            # namespace plugin long
            SETTINGS = {"PLUGINS": ["pelican.plugins.ns_plugin"]}
            plugins = load_plugins(SETTINGS)
            self.assertEqual(len(plugins), 1, plugins)
            self.assertEqual({"pelican.plugins.ns_plugin"}, get_plugin_names(plugins))

            # normal and namespace plugin
            SETTINGS = {
                "PLUGINS": ["normal_plugin", "ns_plugin"],
                "PLUGIN_PATHS": [self._NORMAL_PLUGIN_FOLDER],
            }
            plugins = load_plugins(SETTINGS)
            self.assertEqual(len(plugins), 2, plugins)
            self.assertEqual(
                {"normal_plugin", "pelican.plugins.ns_plugin"},
                get_plugin_names(plugins),
            )

    def test_get_plugin_name(self):
        self.assertEqual(
            get_plugin_name(normal_plugin),
            "pelican.tests.dummy_plugins.normal_plugin.normal_plugin",
        )

        class NoopPlugin:
            def register(self):
                pass

        self.assertEqual(
            get_plugin_name(NoopPlugin),
            "PluginTest.test_get_plugin_name.<locals>.NoopPlugin",
        )
        self.assertEqual(
            get_plugin_name(NoopPlugin()),
            "PluginTest.test_get_plugin_name.<locals>.NoopPlugin",
        )

    def test_plugin_enabled(self):
        def get_plugin_names(plugins):
            return [get_plugin_name(p) for p in plugins]

        with tmp_namespace_path(self._NS_PLUGIN_FOLDER):
            # with no `PLUGINS` setting, load namespace plugins
            SETTINGS = {}
            plugins = get_plugin_names(load_plugins(SETTINGS))
            self.assertTrue(plugin_enabled("ns_plugin", plugins))
            self.assertTrue(plugin_enabled("pelican.plugins.ns_plugin", plugins))
            self.assertFalse(plugin_enabled("normal_plugin", plugins))
            self.assertFalse(plugin_enabled("unknown", plugins))

            # disable namespace plugins with `PLUGINS = []`
            SETTINGS = {"PLUGINS": []}
            plugins = get_plugin_names(load_plugins(SETTINGS))
            self.assertFalse(plugin_enabled("ns_plugin", plugins))
            self.assertFalse(plugin_enabled("pelican.plugins.ns_plugin", plugins))
            self.assertFalse(plugin_enabled("normal_plugin", plugins))
            self.assertFalse(plugin_enabled("unknown", plugins))

            # with `PLUGINS`, load only specified plugins

            # normal plugin
            SETTINGS = {
                "PLUGINS": ["normal_plugin"],
                "PLUGIN_PATHS": [self._NORMAL_PLUGIN_FOLDER],
            }
            plugins = get_plugin_names(load_plugins(SETTINGS))
            self.assertFalse(plugin_enabled("ns_plugin", plugins))
            self.assertFalse(plugin_enabled("pelican.plugins.ns_plugin", plugins))
            self.assertTrue(plugin_enabled("normal_plugin", plugins))
            self.assertFalse(plugin_enabled("unknown", plugins))

            # normal submodule/subpackage plugins
            SETTINGS = {
                "PLUGINS": [
                    "normal_submodule_plugin.subplugin",
                    "normal_submodule_plugin.subpackage.subpackage",
                ],
                "PLUGIN_PATHS": [self._NORMAL_PLUGIN_FOLDER],
            }
            plugins = get_plugin_names(load_plugins(SETTINGS))
            self.assertFalse(plugin_enabled("ns_plugin", plugins))
            self.assertFalse(plugin_enabled("pelican.plugins.ns_plugin", plugins))
            self.assertFalse(plugin_enabled("normal_plugin", plugins))
            self.assertFalse(plugin_enabled("unknown", plugins))

            # namespace plugin short
            SETTINGS = {"PLUGINS": ["ns_plugin"]}
            plugins = get_plugin_names(load_plugins(SETTINGS))
            self.assertTrue(plugin_enabled("ns_plugin", plugins))
            self.assertTrue(plugin_enabled("pelican.plugins.ns_plugin", plugins))
            self.assertFalse(plugin_enabled("normal_plugin", plugins))
            self.assertFalse(plugin_enabled("unknown", plugins))

            # namespace plugin long
            SETTINGS = {"PLUGINS": ["pelican.plugins.ns_plugin"]}
            plugins = get_plugin_names(load_plugins(SETTINGS))
            self.assertTrue(plugin_enabled("ns_plugin", plugins))
            self.assertTrue(plugin_enabled("pelican.plugins.ns_plugin", plugins))
            self.assertFalse(plugin_enabled("normal_plugin", plugins))
            self.assertFalse(plugin_enabled("unknown", plugins))

            # normal and namespace plugin
            SETTINGS = {
                "PLUGINS": ["normal_plugin", "ns_plugin"],
                "PLUGIN_PATHS": [self._NORMAL_PLUGIN_FOLDER],
            }
            plugins = get_plugin_names(load_plugins(SETTINGS))
            self.assertTrue(plugin_enabled("ns_plugin", plugins))
            self.assertTrue(plugin_enabled("pelican.plugins.ns_plugin", plugins))
            self.assertTrue(plugin_enabled("normal_plugin", plugins))
            self.assertFalse(plugin_enabled("unknown", plugins))

    def test_blinker_is_ordered(self):
        """ensure that call order is connetion order"""
        dummy_signal = signal("dummpy_signal")

        functions = []
        expected = []
        for i in range(50):
            # function appends value of i to a list
            def func(input, i=i):
                input.append(i)

            functions.append(func)
            # we expect functions to be run in the connection order
            dummy_signal.connect(func)
            expected.append(i)

        input = []
        dummy_signal.send(input)
        self.assertEqual(input, expected)



import os
from shutil import rmtree
from tempfile import mkdtemp
from unittest.mock import MagicMock

from pelican.generators import ArticlesGenerator, PagesGenerator
from pelican.tests.support import get_context, get_settings, unittest

CUR_DIR = os.path.dirname(__file__)
CONTENT_DIR = os.path.join(CUR_DIR, "content")


class TestCache(unittest.TestCase):
    def setUp(self):
        self.temp_cache = mkdtemp(prefix="pelican_cache.")

    def tearDown(self):
        rmtree(self.temp_cache)

    def _get_cache_enabled_settings(self):
        settings = get_settings()
        settings["CACHE_CONTENT"] = True
        settings["LOAD_CONTENT_CACHE"] = True
        settings["CACHE_PATH"] = self.temp_cache
        return settings

    def test_generator_caching(self):
        """Test that cached and uncached content is same in generator level"""
        settings = self._get_cache_enabled_settings()
        settings["CONTENT_CACHING_LAYER"] = "generator"
        settings["PAGE_PATHS"] = ["TestPages"]
        settings["DEFAULT_DATE"] = (1970, 1, 1)
        settings["READERS"] = {"asc": None}
        context = get_context(settings)

        def sorted_titles(items):
            return sorted(item.title for item in items)

        # Articles
        generator = ArticlesGenerator(
            context=context.copy(),
            settings=settings,
            path=CONTENT_DIR,
            theme=settings["THEME"],
            output_path=None,
        )
        generator.generate_context()
        uncached_articles = sorted_titles(generator.articles)
        uncached_drafts = sorted_titles(generator.drafts)

        generator = ArticlesGenerator(
            context=context.copy(),
            settings=settings,
            path=CONTENT_DIR,
            theme=settings["THEME"],
            output_path=None,
        )
        generator.generate_context()
        cached_articles = sorted_titles(generator.articles)
        cached_drafts = sorted_titles(generator.drafts)

        self.assertEqual(uncached_articles, cached_articles)
        self.assertEqual(uncached_drafts, cached_drafts)

        # Pages
        generator = PagesGenerator(
            context=context.copy(),
            settings=settings,
            path=CUR_DIR,
            theme=settings["THEME"],
            output_path=None,
        )
        generator.generate_context()
        uncached_pages = sorted_titles(generator.pages)
        uncached_hidden_pages = sorted_titles(generator.hidden_pages)
        uncached_draft_pages = sorted_titles(generator.draft_pages)

        generator = PagesGenerator(
            context=context.copy(),
            settings=settings,
            path=CUR_DIR,
            theme=settings["THEME"],
            output_path=None,
        )
        generator.generate_context()
        cached_pages = sorted_titles(generator.pages)
        cached_hidden_pages = sorted_titles(generator.hidden_pages)
        cached_draft_pages = sorted_titles(generator.draft_pages)

        self.assertEqual(uncached_pages, cached_pages)
        self.assertEqual(uncached_hidden_pages, cached_hidden_pages)
        self.assertEqual(uncached_draft_pages, cached_draft_pages)

    def test_reader_caching(self):
        """Test that cached and uncached content is same in reader level"""
        settings = self._get_cache_enabled_settings()
        settings["CONTENT_CACHING_LAYER"] = "reader"
        settings["PAGE_PATHS"] = ["TestPages"]
        settings["DEFAULT_DATE"] = (1970, 1, 1)
        settings["READERS"] = {"asc": None}
        context = get_context(settings)

        def sorted_titles(items):
            return sorted(item.title for item in items)

        # Articles
        generator = ArticlesGenerator(
            context=context.copy(),
            settings=settings,
            path=CONTENT_DIR,
            theme=settings["THEME"],
            output_path=None,
        )
        generator.generate_context()
        uncached_articles = sorted_titles(generator.articles)
        uncached_drafts = sorted_titles(generator.drafts)

        generator = ArticlesGenerator(
            context=context.copy(),
            settings=settings,
            path=CONTENT_DIR,
            theme=settings["THEME"],
            output_path=None,
        )
        generator.generate_context()
        cached_articles = sorted_titles(generator.articles)
        cached_drafts = sorted_titles(generator.drafts)

        self.assertEqual(uncached_articles, cached_articles)
        self.assertEqual(uncached_drafts, cached_drafts)

        # Pages
        generator = PagesGenerator(
            context=context.copy(),
            settings=settings,
            path=CUR_DIR,
            theme=settings["THEME"],
            output_path=None,
        )
        generator.generate_context()
        uncached_pages = sorted_titles(generator.pages)
        uncached_hidden_pages = sorted_titles(generator.hidden_pages)

        generator = PagesGenerator(
            context=context.copy(),
            settings=settings,
            path=CUR_DIR,
            theme=settings["THEME"],
            output_path=None,
        )
        generator.generate_context()
        cached_pages = sorted_titles(generator.pages)
        cached_hidden_pages = sorted_titles(generator.hidden_pages)

        self.assertEqual(uncached_pages, cached_pages)
        self.assertEqual(uncached_hidden_pages, cached_hidden_pages)

    def test_article_object_caching(self):
        """Test Article objects caching at the generator level"""
        settings = self._get_cache_enabled_settings()
        settings["CONTENT_CACHING_LAYER"] = "generator"
        settings["DEFAULT_DATE"] = (1970, 1, 1)
        settings["READERS"] = {"asc": None}
        context = get_context(settings)

        generator = ArticlesGenerator(
            context=context.copy(),
            settings=settings,
            path=CONTENT_DIR,
            theme=settings["THEME"],
            output_path=None,
        )
        generator.generate_context()
        self.assertTrue(hasattr(generator, "_cache"))

        generator = ArticlesGenerator(
            context=context.copy(),
            settings=settings,
            path=CONTENT_DIR,
            theme=settings["THEME"],
            output_path=None,
        )
        generator.readers.read_file = MagicMock()
        generator.generate_context()
        """
        7 files don't get cached because they were not valid
        - article_with_attributes_containing_double_quotes.html
        - article_with_comments.html
        - article_with_null_attributes.html
        - 2012-11-30_md_w_filename_meta#foo-bar.md
        - empty.md
        - empty_with_bom.md
        - article_skip.md
        """
        self.assertEqual(generator.readers.read_file.call_count, 7)

    def test_article_reader_content_caching(self):
        """Test raw article content caching at the reader level"""
        settings = self._get_cache_enabled_settings()
        settings["READERS"] = {"asc": None}
        context = get_context(settings)

        generator = ArticlesGenerator(
            context=context.copy(),
            settings=settings,
            path=CONTENT_DIR,
            theme=settings["THEME"],
            output_path=None,
        )
        generator.generate_context()
        self.assertTrue(hasattr(generator.readers, "_cache"))

        generator = ArticlesGenerator(
            context=context.copy(),
            settings=settings,
            path=CONTENT_DIR,
            theme=settings["THEME"],
            output_path=None,
        )
        readers = generator.readers.readers
        for reader in readers.values():
            reader.read = MagicMock()
        generator.generate_context()
        for reader in readers.values():
            self.assertEqual(reader.read.call_count, 0)

    def test_article_ignore_cache(self):
        """Test that all the articles are read again when not loading cache

        used in --ignore-cache or autoreload mode"""
        settings = self._get_cache_enabled_settings()
        settings["READERS"] = {"asc": None}
        context = get_context(settings)

        generator = ArticlesGenerator(
            context=context.copy(),
            settings=settings,
            path=CONTENT_DIR,
            theme=settings["THEME"],
            output_path=None,
        )
        generator.readers.read_file = MagicMock()
        generator.generate_context()
        self.assertTrue(hasattr(generator, "_cache_open"))
        orig_call_count = generator.readers.read_file.call_count

        settings["LOAD_CONTENT_CACHE"] = False
        generator = ArticlesGenerator(
            context=context.copy(),
            settings=settings,
            path=CONTENT_DIR,
            theme=settings["THEME"],
            output_path=None,
        )
        generator.readers.read_file = MagicMock()
        generator.generate_context()
        self.assertEqual(generator.readers.read_file.call_count, orig_call_count)

    def test_page_object_caching(self):
        """Test Page objects caching at the generator level"""
        settings = self._get_cache_enabled_settings()
        settings["CONTENT_CACHING_LAYER"] = "generator"
        settings["PAGE_PATHS"] = ["TestPages"]
        settings["READERS"] = {"asc": None}
        context = get_context(settings)

        generator = PagesGenerator(
            context=context.copy(),
            settings=settings,
            path=CUR_DIR,
            theme=settings["THEME"],
            output_path=None,
        )
        generator.generate_context()
        self.assertTrue(hasattr(generator, "_cache"))

        generator = PagesGenerator(
            context=context.copy(),
            settings=settings,
            path=CUR_DIR,
            theme=settings["THEME"],
            output_path=None,
        )
        generator.readers.read_file = MagicMock()
        generator.generate_context()
        """
        1 File doesn't get cached because it was not valid
        - bad_page.rst
        """
        self.assertEqual(generator.readers.read_file.call_count, 1)

    def test_page_reader_content_caching(self):
        """Test raw page content caching at the reader level"""
        settings = self._get_cache_enabled_settings()
        settings["PAGE_PATHS"] = ["TestPages"]
        settings["READERS"] = {"asc": None}
        context = get_context(settings)

        generator = PagesGenerator(
            context=context.copy(),
            settings=settings,
            path=CUR_DIR,
            theme=settings["THEME"],
            output_path=None,
        )
        generator.generate_context()
        self.assertTrue(hasattr(generator.readers, "_cache"))

        generator = PagesGenerator(
            context=context.copy(),
            settings=settings,
            path=CUR_DIR,
            theme=settings["THEME"],
            output_path=None,
        )
        readers = generator.readers.readers
        for reader in readers.values():
            reader.read = MagicMock()
        generator.generate_context()
        for reader in readers.values():
            self.assertEqual(reader.read.call_count, 0)

    def test_page_ignore_cache(self):
        """Test that all the pages are read again when not loading cache

        used in --ignore_cache or autoreload mode"""
        settings = self._get_cache_enabled_settings()
        settings["PAGE_PATHS"] = ["TestPages"]
        settings["READERS"] = {"asc": None}
        context = get_context(settings)

        generator = PagesGenerator(
            context=context.copy(),
            settings=settings,
            path=CUR_DIR,
            theme=settings["THEME"],
            output_path=None,
        )
        generator.readers.read_file = MagicMock()
        generator.generate_context()
        self.assertTrue(hasattr(generator, "_cache_open"))
        orig_call_count = generator.readers.read_file.call_count

        settings["LOAD_CONTENT_CACHE"] = False
        generator = PagesGenerator(
            context=context.copy(),
            settings=settings,
            path=CUR_DIR,
            theme=settings["THEME"],
            output_path=None,
        )
        generator.readers.read_file = MagicMock()
        generator.generate_context()
        self.assertEqual(generator.readers.read_file.call_count, orig_call_count)



import unittest

from pelican import get_config, parse_arguments


class TestParseOverrides(unittest.TestCase):
    def test_flags(self):
        for flag in ["-e", "--extra-settings"]:
            args = parse_arguments([flag, "k=1"])
            self.assertDictEqual(args.overrides, {"k": 1})

    def test_parse_multiple_items(self):
        args = parse_arguments("-e k1=1 k2=2".split())
        self.assertDictEqual(args.overrides, {"k1": 1, "k2": 2})

    def test_parse_valid_json(self):
        json_values_python_values_map = {
            '""': "",
            "null": None,
            '"string"': "string",
            '["foo", 12, "4", {}]': ["foo", 12, "4", {}],
        }
        for k, v in json_values_python_values_map.items():
            args = parse_arguments(["-e", "k=" + k])
            self.assertDictEqual(args.overrides, {"k": v})

    def test_parse_invalid_syntax(self):
        invalid_items = ["k= 1", "k =1", "k", "k v"]
        for item in invalid_items:
            with self.assertRaises(ValueError):
                parse_arguments(f"-e {item}".split())

    def test_parse_invalid_json(self):
        invalid_json = {
            "",
            "False",
            "True",
            "None",
            "some other string",
            '{"foo": bar}',
            "[foo]",
        }
        for v in invalid_json:
            with self.assertRaises(ValueError):
                parse_arguments(["-e ", "k=" + v])


class TestGetConfigFromArgs(unittest.TestCase):
    def test_overrides_known_keys(self):
        args = parse_arguments(
            [
                "-e",
                "DELETE_OUTPUT_DIRECTORY=false",
                'OUTPUT_RETENTION=["1.txt"]',
                'SITENAME="Title"',
            ]
        )
        config = get_config(args)
        config_must_contain = {
            "DELETE_OUTPUT_DIRECTORY": False,
            "OUTPUT_RETENTION": ["1.txt"],
            "SITENAME": "Title",
        }
        self.assertDictEqual(config, {**config, **config_must_contain})

    def test_overrides_non_default_type(self):
        args = parse_arguments(
            [
                "-e",
                "DISPLAY_PAGES_ON_MENU=123",
                "PAGE_TRANSLATION_ID=null",
                'TRANSLATION_FEED_RSS_URL="someurl"',
            ]
        )
        config = get_config(args)
        config_must_contain = {
            "DISPLAY_PAGES_ON_MENU": 123,
            "PAGE_TRANSLATION_ID": None,
            "TRANSLATION_FEED_RSS_URL": "someurl",
        }
        self.assertDictEqual(config, {**config, **config_must_contain})



AUTHOR = "Alexis Métaireau"
SITENAME = "Alexis' log"
SITESUBTITLE = "A personal blog."
SITEURL = "http://blog.notmyidea.org"
TIMEZONE = "Europe/Paris"

# can be useful in development, but set to False when you're ready to publish
RELATIVE_URLS = True

GITHUB_URL = "http://github.com/ametaireau/"
DISQUS_SITENAME = "blog-notmyidea"
REVERSE_CATEGORY_ORDER = True
LOCALE = "C"
DEFAULT_PAGINATION = 4
DEFAULT_DATE = (2012, 3, 2, 14, 1, 1)

FEED_ALL_RSS = "feeds/all.rss.xml"
CATEGORY_FEED_RSS = "feeds/{slug}.rss.xml"

LINKS = (
    ("Biologeek", "http://biologeek.org"),
    ("Filyb", "http://filyb.info/"),
    ("Libert-fr", "http://www.libert-fr.com"),
    ("N1k0", "http://prendreuncafe.com/blog/"),
    ("Tarek Ziadé", "http://ziade.org/blog"),
    ("Zubin Mithra", "http://zubin71.wordpress.com/"),
)

SOCIAL = (
    ("twitter", "http://twitter.com/ametaireau"),
    ("lastfm", "http://lastfm.com/user/akounet"),
    ("github", "http://github.com/ametaireau"),
)

# global metadata to all the contents
DEFAULT_METADATA = {"yeah": "it is"}

# path-specific metadata
EXTRA_PATH_METADATA = {
    "extra/robots.txt": {"path": "robots.txt"},
}

# static paths will be copied without parsing their contents
STATIC_PATHS = [
    "images",
    "extra/robots.txt",
]

# custom page generated with a jinja2 template
TEMPLATE_PAGES = {"pages/jinja2_template.html": "jinja2_template.html"}

# there is no other HTML content
READERS = {"html": None}

# code blocks with line numbers
PYGMENTS_RST_OPTIONS = {"linenos": "table"}

# foobar will not be used, because it's not in caps. All configuration keys
# have to be in caps
foobar = "barbaz"
